import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def actuator_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int, typing.Any]] = '',
        name: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = ""):
    ''' Add an actuator to the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type, Type of actuator to add
    :type type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param name: Name, Name of the Actuator to add
    :type name: typing.Union[str, typing.Any]
    :param object: Object, Name of the Object to add the Actuator to
    :type object: typing.Union[str, typing.Any]
    '''

    pass


def actuator_move(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        actuator: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = "",
        direction: typing.Optional[typing.Any] = 'UP'):
    ''' Move Actuator

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param actuator: Actuator, Name of the actuator to edit
    :type actuator: typing.Union[str, typing.Any]
    :param object: Object, Name of the object the actuator belongs to
    :type object: typing.Union[str, typing.Any]
    :param direction: Direction, Move Up or Down
    :type direction: typing.Optional[typing.Any]
    '''

    pass


def actuator_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        actuator: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = ""):
    ''' Remove an actuator from the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param actuator: Actuator, Name of the actuator to edit
    :type actuator: typing.Union[str, typing.Any]
    :param object: Object, Name of the object the actuator belongs to
    :type object: typing.Union[str, typing.Any]
    '''

    pass


def controller_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int]] = 'LOGIC_AND',
        name: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = ""):
    ''' Add a controller to the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type, Type of controller to add
    :type type: typing.Optional[typing.Union[str, int]]
    :param name: Name, Name of the Controller to add
    :type name: typing.Union[str, typing.Any]
    :param object: Object, Name of the Object to add the Controller to
    :type object: typing.Union[str, typing.Any]
    '''

    pass


def controller_move(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        controller: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = "",
        direction: typing.Optional[typing.Any] = 'UP'):
    ''' Move Controller

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param controller: Controller, Name of the controller to edit
    :type controller: typing.Union[str, typing.Any]
    :param object: Object, Name of the object the controller belongs to
    :type object: typing.Union[str, typing.Any]
    :param direction: Direction, Move Up or Down
    :type direction: typing.Optional[typing.Any]
    '''

    pass


def controller_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        controller: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = ""):
    ''' Remove a controller from the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param controller: Controller, Name of the controller to edit
    :type controller: typing.Union[str, typing.Any]
    :param object: Object, Name of the object the controller belongs to
    :type object: typing.Union[str, typing.Any]
    '''

    pass


def custom_object_create(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        class_name: typing.Union[str, typing.Any] = "module.MyObject"):
    ''' Create a KX_GameObject subclass and attach it to the selected object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param class_name: MyObject, The class name with module (module.ClassName)
    :type class_name: typing.Union[str, typing.Any]
    '''

    pass


def custom_object_register(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        class_name: typing.Union[str, typing.Any] = "module.MyObject"):
    ''' Use a custom KX_GameObject subclass for the selected object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param class_name: MyObject, The class name with module (module.ClassName)
    :type class_name: typing.Union[str, typing.Any]
    '''

    pass


def custom_object_reload(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Reload custom object from the source script

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def custom_object_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Remove this custom class from the object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def links_cut(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        path: typing.Optional[bpy.types.bpy_prop_collection[
            'bpy.types.OperatorMousePath']] = None,
        cursor: typing.Optional[typing.Any] = 12):
    ''' Remove logic brick connections

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param path: Path
    :type path: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']]
    :param cursor: Cursor
    :type cursor: typing.Optional[typing.Any]
    '''

    pass


def properties(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Toggle the properties region visibility

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def python_component_create(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        component_name: typing.Union[str, typing.Any] = "module.Component"):
    ''' Create a Python component to the selected object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param component_name: Component, The component class name with module (module.ComponentName)
    :type component_name: typing.Union[str, typing.Any]
    '''

    pass


def python_component_move_down(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        index: typing.Optional[typing.Any] = 0):
    ''' Move this component down in the list

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param index: Index, Component index to move
    :type index: typing.Optional[typing.Any]
    '''

    pass


def python_component_move_up(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        index: typing.Optional[typing.Any] = 0):
    ''' Move this component up in the list

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param index: Index, Component index to move
    :type index: typing.Optional[typing.Any]
    '''

    pass


def python_component_register(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        component_name: typing.Union[str, typing.Any] = "module.Component"):
    ''' Add a Python component to the selected object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param component_name: Component, The component class name with module (module.ComponentName)
    :type component_name: typing.Union[str, typing.Any]
    '''

    pass


def python_component_reload(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        index: typing.Optional[typing.Any] = 0):
    ''' Reload component from the source script

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param index: Index, Component index to reload
    :type index: typing.Optional[typing.Any]
    '''

    pass


def python_component_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        index: typing.Optional[typing.Any] = 0):
    ''' Remove this component from the object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param index: Index, Component index to remove
    :type index: typing.Optional[typing.Any]
    '''

    pass


def region_flip(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Toggle the properties region's alignment (left/right)

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def sensor_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int, typing.Any]] = '',
        name: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = ""):
    ''' Add a sensor to the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type, Type of sensor to add
    :type type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param name: Name, Name of the Sensor to add
    :type name: typing.Union[str, typing.Any]
    :param object: Object, Name of the Object to add the Sensor to
    :type object: typing.Union[str, typing.Any]
    '''

    pass


def sensor_move(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        sensor: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = "",
        direction: typing.Optional[typing.Any] = 'UP'):
    ''' Move Sensor

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param sensor: Sensor, Name of the sensor to edit
    :type sensor: typing.Union[str, typing.Any]
    :param object: Object, Name of the object the sensor belongs to
    :type object: typing.Union[str, typing.Any]
    :param direction: Direction, Move Up or Down
    :type direction: typing.Optional[typing.Any]
    '''

    pass


def sensor_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        sensor: typing.Union[str, typing.Any] = "",
        object: typing.Union[str, typing.Any] = ""):
    ''' Remove a sensor from the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param sensor: Sensor, Name of the sensor to edit
    :type sensor: typing.Union[str, typing.Any]
    :param object: Object, Name of the object the sensor belongs to
    :type object: typing.Union[str, typing.Any]
    '''

    pass


def view_all(override_context: typing.Optional[
        typing.Union[typing.Dict, 'bpy.types.Context']] = None,
             execution_context: typing.Optional[typing.Union[str, int]] = None,
             undo: typing.Optional[bool] = None):
    ''' Resize view so you can see all logic bricks

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass



import sys
import typing
from . import image_button
from . import list_box
from . import image
from . import system
from . import text_input
from . import theme
from . import text_block
from . import widget
from . import frame_button
from . import progress_bar
from . import frame
from . import label

GenericType = typing.TypeVar("GenericType")



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class NewSectionProxy:
    name = None
    ''' '''

    parser = None
    ''' '''

    def clear(self):
        ''' 

        '''
        pass

    def get(self, option, fallback, raw, vars, _impl, kwargs):
        ''' 

        '''
        pass

    def items(self):
        ''' 

        '''
        pass

    def keys(self):
        ''' 

        '''
        pass

    def pop(self, key, default):
        ''' 

        '''
        pass

    def popitem(self):
        ''' 

        '''
        pass

    def setdefault(self, key, default):
        ''' 

        '''
        pass

    def update(self, other, kwds):
        ''' 

        '''
        pass

    def values(self):
        ''' 

        '''
        pass


class Theme:
    BOOLEAN_STATES = None
    ''' '''

    NONSPACECRE = None
    ''' '''

    OPTCRE = None
    ''' '''

    OPTCRE_NV = None
    ''' '''

    SECTCRE = None
    ''' '''

    converters = None
    ''' '''

    path = None
    ''' '''

    def add_section(self, section):
        ''' 

        '''
        pass

    def clear(self):
        ''' 

        '''
        pass

    def defaults(self):
        ''' 

        '''
        pass

    def get(self, section, option, raw, vars, fallback):
        ''' 

        '''
        pass

    def getboolean(self, section, option, raw, vars, fallback, kwargs):
        ''' 

        '''
        pass

    def getfloat(self, section, option, raw, vars, fallback, kwargs):
        ''' 

        '''
        pass

    def getint(self, section, option, raw, vars, fallback, kwargs):
        ''' 

        '''
        pass

    def has_option(self, section, option):
        ''' 

        '''
        pass

    def has_section(self, section):
        ''' 

        '''
        pass

    def items(self, section, raw, vars):
        ''' 

        '''
        pass

    def keys(self):
        ''' 

        '''
        pass

    def options(self, section):
        ''' 

        '''
        pass

    def optionxform(self, optionstr):
        ''' 

        '''
        pass

    def pop(self, key, default):
        ''' 

        '''
        pass

    def popitem(self):
        ''' 

        '''
        pass

    def read(self, filenames, encoding):
        ''' 

        '''
        pass

    def read_dict(self, dictionary, source):
        ''' 

        '''
        pass

    def read_file(self, f, source):
        ''' 

        '''
        pass

    def read_string(self, string, source):
        ''' 

        '''
        pass

    def readfp(self, fp, filename):
        ''' 

        '''
        pass

    def remove_option(self, section, option):
        ''' 

        '''
        pass

    def remove_section(self, section):
        ''' 

        '''
        pass

    def sections(self):
        ''' 

        '''
        pass

    def set(self, section, option, value):
        ''' 

        '''
        pass

    def setdefault(self, key, default):
        ''' 

        '''
        pass

    def supports(self, widget):
        ''' 

        '''
        pass

    def update(self, other, kwds):
        ''' 

        '''
        pass

    def values(self):
        ''' 

        '''
        pass

    def warn_legacy(self, section):
        ''' 

        '''
        pass

    def warn_support(self, section):
        ''' 

        '''
        pass

    def write(self, fp, space_around_delimiters):
        ''' 

        '''
        pass



import sys
import typing
from . import types
from . import events
from . import logic
from . import render
from . import app
from . import texture
from . import constraints

GenericType = typing.TypeVar("GenericType")



import sys
import typing
import bgui.widget

GenericType = typing.TypeVar("GenericType")


class TextInput(bgui.widget.Widget):
    children = None
    ''' '''

    on_active = None
    ''' '''

    on_click = None
    ''' '''

    on_enter_key = None
    ''' '''

    on_hover = None
    ''' '''

    on_mouse_enter = None
    ''' '''

    on_mouse_exit = None
    ''' '''

    on_release = None
    ''' '''

    parent = None
    ''' '''

    position = None
    ''' '''

    prefix = None
    ''' '''

    size = None
    ''' '''

    system = None
    ''' '''

    text = None
    ''' '''

    theme_options = None
    ''' '''

    theme_section = None
    ''' '''

    def activate(self):
        ''' 

        '''
        pass

    def add_animation(self, animation):
        ''' 

        '''
        pass

    def calc_mouse_cursor(self, pos):
        ''' 

        '''
        pass

    def deactivate(self):
        ''' 

        '''
        pass

    def find_mouse_slice(self, pos):
        ''' 

        '''
        pass

    def move(self, position, time, callback):
        ''' 

        '''
        pass

    def select_all(self):
        ''' 

        '''
        pass

    def select_none(self):
        ''' 

        '''
        pass

    def swapcolors(self, state):
        ''' 

        '''
        pass

    def update_selection(self):
        ''' 

        '''
        pass



import sys
import typing
import bgui.widget

GenericType = typing.TypeVar("GenericType")


class Frame(bgui.widget.Widget):
    children = None
    ''' '''

    on_active = None
    ''' '''

    on_click = None
    ''' '''

    on_hover = None
    ''' '''

    on_mouse_enter = None
    ''' '''

    on_mouse_exit = None
    ''' '''

    on_release = None
    ''' '''

    parent = None
    ''' '''

    position = None
    ''' '''

    size = None
    ''' '''

    system = None
    ''' '''

    theme_options = None
    ''' '''

    theme_section = None
    ''' '''

    def add_animation(self, animation):
        ''' 

        '''
        pass

    def move(self, position, time, callback):
        ''' 

        '''
        pass
